@@ -1,4 +1,5 @@
 import chromadb
+from chromadb.api.types import OneOrMany
 from chromadb.config import Settings as ChromaSettings
 from langchain_chroma import Chroma as LangChainChroma
 from ally_ai_core import Settings
@@ -40,3 +41,16 @@ class Chroma(LangChainChroma):
                              embedding_function=embeddingModel,
                              create_collection_if_not_exists=False,
                              **kwargs)
+
+    def query(self, 
+        query_texts: Optional[OneOrMany[str]] = None,
+        n_results: int = 10,
+        include: chromadb.Include = ["metadatas", "documents", "distances"]):
+
+        query_embeddings = [self._embedding_function.embed_query(query_text) for query_text in query_texts]
+    
+        return self._collection.query(
+            query_embeddings=query_embeddings, 
+            n_results=n_results,
+            include=include
+        )
\ No newline at end of file
